==> react-hook-result-1.0.0.tgz: package/index.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __commonJS = (cb, mod) => function __require() {
  return mod || (0, cb[__getOwnPropNames(cb)[0]])((mod = { exports: {} }).exports, mod), mod.exports;
};
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// node_modules/@ptolemy2002/js-utils/index.js
var require_js_utils = __commonJS({
  "node_modules/@ptolemy2002/js-utils/index.js"(exports, module2) {
    var __defProp2 = Object.defineProperty;
    var __getOwnPropDesc2 = Object.getOwnPropertyDescriptor;
    var __getOwnPropNames2 = Object.getOwnPropertyNames;
    var __hasOwnProp2 = Object.prototype.hasOwnProperty;
    var __export2 = (target, all) => {
      for (var name in all)
        __defProp2(target, name, { get: all[name], enumerable: true });
    };
    var __copyProps2 = (to, from, except, desc) => {
      if (from && typeof from === "object" || typeof from === "function") {
        for (let key of __getOwnPropNames2(from))
          if (!__hasOwnProp2.call(to, key) && key !== except)
            __defProp2(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc2(from, key)) || desc.enumerable });
      }
      return to;
    };
    var __toCommonJS2 = (mod) => __copyProps2(__defProp2({}, "__esModule", { value: true }), mod);
    var src_exports2 = {};
    __export2(src_exports2, {
      Callable: () => Callable,
      ext_getAllProperties: () => ext_getAllProperties,
      ext_hasNestedProperty: () => ext_hasNestedProperty,
      ext_hasOwnNestedProperty: () => ext_hasOwnNestedProperty,
      ext_hasProperty: () => ext_hasProperty2,
      getAllProperties: () => getAllProperties,
      hasNestedProperty: () => hasNestedProperty,
      hasProperty: () => hasProperty,
      isNullOrUndefined: () => isNullOrUndefined,
      listInPlainEnglish: () => listInPlainEnglish,
      loadExtension: () => loadExtension2,
      unloadExtension: () => unloadExtension
    });
    module2.exports = __toCommonJS2(src_exports2);
    function hasNestedProperty(self, prop = "", hasPropCallback = (o, p) => o.hasOwnProperty(p)) {
      if (typeof prop === "string") prop = prop.split(".");
      if (!Array.isArray(prop)) return hasPropCallback(self, prop);
      let obj = self;
      for (let i = 0; i < prop.length; i++) {
        const p = prop[i];
        if (!obj) return false;
        if (!hasPropCallback(obj, p)) return false;
        obj = obj[p];
      }
      return true;
    }
    function ext_hasOwnNestedProperty(prop = "") {
      return hasNestedProperty(this, prop);
    }
    function getAllProperties(self) {
      let allProps = [], curr = self;
      do {
        let props = Object.getOwnPropertyNames(curr);
        props.forEach(function(prop) {
          if (allProps.indexOf(prop) === -1) {
            allProps.push(prop);
          }
        });
      } while (curr = Object.getPrototypeOf(curr));
      return allProps;
    }
    function ext_getAllProperties() {
      return getAllProperties(this);
    }
    function hasProperty(self, prop) {
      let curr = self;
      do {
        if (curr.hasOwnProperty(prop)) return true;
      } while (curr = Object.getPrototypeOf(curr));
      return false;
    }
    function ext_hasProperty2(prop) {
      return hasProperty(this, prop);
    }
    function ext_hasNestedProperty(prop) {
      return hasNestedProperty(this, prop, (o, p) => hasProperty(o, p));
    }
    function loadExtension2(name, func, base = Object) {
      if (hasProperty(base.prototype, name)) return;
      Object.defineProperty(base.prototype, name, {
        value: func,
        enumerable: false,
        writable: true,
        configurable: true
      });
    }
    function unloadExtension(name, base = Object) {
      delete base.prototype[name];
    }
    function listInPlainEnglish(list, { max = void 0, conjunction = "and" } = {}) {
      if (max === void 0) max = list.length;
      if (list.length === 0) {
        return "";
      }
      if (list.length === 1) {
        return list[0];
      }
      if (list.length === 2) {
        return `${list[0]} ${conjunction} ${list[1]}`;
      }
      list = list.map((v, i) => {
        if (i === list.length - 1) return v;
        if (v.endsWith(`"`)) {
          return v.slice(0, -1) + `," `;
        } else if (v.endsWith(`'`)) {
          return v.slice(0, -1) + `,' `;
        } else {
          return v + ", ";
        }
      });
      if (list.length > max) {
        return `${list.slice(0, max).join("")}${conjunction} ${list.length - max} more`;
      } else {
        return `${list.slice(0, -1).join("")}${conjunction} ${list[list.length - 1]}`;
      }
    }
    function isNullOrUndefined(v) {
      return v === null || v === void 0;
    }
    var Callable = class extends Function {
      constructor() {
        super("...args", "return this.__self__.__call__(...args)");
        let self = this.bind(this);
        this.__self__ = self;
        return self;
      }
      // This should be overridden by the subclass
      __call__() {
      }
    };
  }
});

// src/index.js
var src_exports = {};
__export(src_exports, {
  default: () => HookResult
});
module.exports = __toCommonJS(src_exports);
var import_js_utils = __toESM(require_js_utils());
(0, import_js_utils.loadExtension)("hasProperty", import_js_utils.ext_hasProperty, Object);
var HookResult = class {
  data = /* @__PURE__ */ new Map();
  order = [];
  constructor(data = {}, order = []) {
    if (typeof Proxy == "undefined") throw new Error("Proxy is not supported in this environment.");
    this.order = order;
    order.forEach((key) => {
      this.data.set(key, data[key]);
    });
    Object.keys(data).forEach((key) => {
      if (!order.includes(key)) {
        this.data.set(key, data[key]);
      }
    });
    return new Proxy(this, {
      // If the property is not found on the object, get it from the data map
      get: function(target, prop) {
        if (target.hasProperty(prop)) {
          return target[prop];
        } else {
          return target.data.get(prop);
        }
      },
      // If the property is not found on the object, set it in the data map
      set: function(target, prop, value) {
        if (target.hasProperty(prop)) {
          target[prop] = value;
        } else {
          target.data.set(prop, value);
        }
      }
    });
  }
  // This is a generator function: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Statements/function*
  *[Symbol.iterator]() {
    yield* this.data.values();
  }
};

==> react-hook-result-1.0.1.tgz: package/index.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __commonJS = (cb, mod) => function __require() {
  return mod || (0, cb[__getOwnPropNames(cb)[0]])((mod = { exports: {} }).exports, mod), mod.exports;
};
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// node_modules/@ptolemy2002/js-utils/index.js
var require_js_utils = __commonJS({
  "node_modules/@ptolemy2002/js-utils/index.js"(exports, module2) {
    var __defProp2 = Object.defineProperty;
    var __getOwnPropDesc2 = Object.getOwnPropertyDescriptor;
    var __getOwnPropNames2 = Object.getOwnPropertyNames;
    var __hasOwnProp2 = Object.prototype.hasOwnProperty;
    var __export2 = (target, all) => {
      for (var name in all)
        __defProp2(target, name, { get: all[name], enumerable: true });
    };
    var __copyProps2 = (to, from, except, desc) => {
      if (from && typeof from === "object" || typeof from === "function") {
        for (let key of __getOwnPropNames2(from))
          if (!__hasOwnProp2.call(to, key) && key !== except)
            __defProp2(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc2(from, key)) || desc.enumerable });
      }
      return to;
    };
    var __toCommonJS2 = (mod) => __copyProps2(__defProp2({}, "__esModule", { value: true }), mod);
    var src_exports2 = {};
    __export2(src_exports2, {
      Callable: () => Callable,
      ext_getAllProperties: () => ext_getAllProperties,
      ext_hasNestedProperty: () => ext_hasNestedProperty,
      ext_hasOwnNestedProperty: () => ext_hasOwnNestedProperty,
      ext_hasProperty: () => ext_hasProperty2,
      getAllProperties: () => getAllProperties,
      hasNestedProperty: () => hasNestedProperty,
      hasProperty: () => hasProperty,
      isNullOrUndefined: () => isNullOrUndefined,
      listInPlainEnglish: () => listInPlainEnglish,
      loadExtension: () => loadExtension2,
      unloadExtension: () => unloadExtension
    });
    module2.exports = __toCommonJS2(src_exports2);
    function hasNestedProperty(self, prop = "", hasPropCallback = (o, p) => o.hasOwnProperty(p)) {
      if (typeof prop === "string") prop = prop.split(".");
      if (!Array.isArray(prop)) return hasPropCallback(self, prop);
      let obj = self;
      for (let i = 0; i < prop.length; i++) {
        const p = prop[i];
        if (!obj) return false;
        if (!hasPropCallback(obj, p)) return false;
        obj = obj[p];
      }
      return true;
    }
    function ext_hasOwnNestedProperty(prop = "") {
      return hasNestedProperty(this, prop);
    }
    function getAllProperties(self) {
      let allProps = [], curr = self;
      do {
        let props = Object.getOwnPropertyNames(curr);
        props.forEach(function(prop) {
          if (allProps.indexOf(prop) === -1) {
            allProps.push(prop);
          }
        });
      } while (curr = Object.getPrototypeOf(curr));
      return allProps;
    }
    function ext_getAllProperties() {
      return getAllProperties(this);
    }
    function hasProperty(self, prop) {
      let curr = self;
      do {
        if (curr.hasOwnProperty(prop)) return true;
      } while (curr = Object.getPrototypeOf(curr));
      return false;
    }
    function ext_hasProperty2(prop) {
      return hasProperty(this, prop);
    }
    function ext_hasNestedProperty(prop) {
      return hasNestedProperty(this, prop, (o, p) => hasProperty(o, p));
    }
    function loadExtension2(name, func, base = Object) {
      if (hasProperty(base.prototype, name)) return;
      Object.defineProperty(base.prototype, name, {
        value: func,
        enumerable: false,
        writable: true,
        configurable: true
      });
    }
    function unloadExtension(name, base = Object) {
      delete base.prototype[name];
    }
    function listInPlainEnglish(list, { max = void 0, conjunction = "and" } = {}) {
      if (max === void 0) max = list.length;
      if (list.length === 0) {
        return "";
      }
      if (list.length === 1) {
        return list[0];
      }
      if (list.length === 2) {
        return `${list[0]} ${conjunction} ${list[1]}`;
      }
      list = list.map((v, i) => {
        if (i === list.length - 1) return v;
        if (v.endsWith(`"`)) {
          return v.slice(0, -1) + `," `;
        } else if (v.endsWith(`'`)) {
          return v.slice(0, -1) + `,' `;
        } else {
          return v + ", ";
        }
      });
      if (list.length > max) {
        return `${list.slice(0, max).join("")}${conjunction} ${list.length - max} more`;
      } else {
        return `${list.slice(0, -1).join("")}${conjunction} ${list[list.length - 1]}`;
      }
    }
    function isNullOrUndefined(v) {
      return v === null || v === void 0;
    }
    var Callable = class extends Function {
      constructor() {
        super("...args", "return this.__self__.__call__(...args)");
        let self = this.bind(this);
        this.__self__ = self;
        return self;
      }
      // This should be overridden by the subclass
      __call__() {
      }
    };
  }
});

// src/index.js
var src_exports = {};
__export(src_exports, {
  default: () => HookResult
});
module.exports = __toCommonJS(src_exports);
var import_js_utils = __toESM(require_js_utils());
(0, import_js_utils.loadExtension)("hasProperty", import_js_utils.ext_hasProperty, Object);
var HookResult = class {
  _data = /* @__PURE__ */ new Map();
  order = [];
  constructor(data = {}, order = []) {
    if (typeof Proxy == "undefined") throw new Error("Proxy is not supported in this environment.");
    this.order = order;
    order.forEach((key) => {
      this._data.set(key, data[key]);
    });
    Object.keys(data).forEach((key) => {
      if (!order.includes(key)) {
        this._data.set(key, data[key]);
      }
    });
    return new Proxy(this, {
      // If the property is not found on the object, get it from the data map
      get: function(target, prop) {
        if (target.hasProperty(prop)) {
          return target[prop];
        } else {
          return target._data.get(prop);
        }
      },
      // If the property is not found on the object, set it in the data map
      set: function(target, prop, value) {
        if (target.hasProperty(prop)) {
          target[prop] = value;
        } else {
          target._data.set(prop, value);
        }
      }
    });
  }
  // This is a generator function: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Statements/function*
  *[Symbol.iterator]() {
    yield* this._data.values();
  }
};
